==> universal-app-shell-loader-0.2.2.tgz: package/lib/index.js <==
"use strict";

var _require = require('path'),
    join = _require.join;

var _require2 = require('loader-utils'),
    getOptions = _require2.getOptions;

var _require3 = require('fs'),
    existsSync = _require3.existsSync;

var pathToRegexp = require('path-to-regexp');

var babel = require('@babel/core');

var _require4 = require('rax-compile-config'),
    getBabelConfig = _require4.getBabelConfig;

var babelConfig = getBabelConfig();
var historyMemory = {
  hash: 'createHashHistory',
  memory: 'createMemoryHistory',
  browser: 'createBrowserHistory'
};
/**
 * Universal App Shell Loader for Rax.
 */

module.exports = function (content) {
  var _this = this;

  var options = getOptions(this) || {};
  var renderMoudle = options.renderModule || 'rax';

  if (!this.data.appConfig) {
    return content;
  }

  var _this$data$appConfig = this.data.appConfig,
      routes = _this$data$appConfig.routes,
      _this$data$appConfig$ = _this$data$appConfig.historyType,
      historyType = _this$data$appConfig$ === void 0 ? 'hash' : _this$data$appConfig$;

  if (!Array.isArray(routes)) {
    this.emitError(new Error('Unsupported field in app.json: routes.'));
    routes = [];
  }

  var appRender = '';
  var importMods = '';
  /**
   * Weex only support memory history.
   */

  if (options.type === 'weex') {
    historyType = 'memory';
    appRender = 'render(createElement(Entry), null, { driver: DriverUniversal });';
  }
  /**
   * Web only compatible with 750rpx.
   */


  if (options.type === 'web') {
    var appRenderMethod = '';
    importMods += 'import { getCurrentComponent } from "rax-pwa";';

    if (existsSync(join(this.rootContext, 'src/shell/index.jsx'))) {
      // app shell
      appRender += "import Shell from \"" + getDepPath('shell/index', this.rootContext) + "\";";
      appRenderMethod = "\n        // process Shell.getInitialProps\n        // use global props appProps as shell default props\n        const shellProps = {...appProps};\n        if (withSSR && window.__INITIAL_DATA__.shellData !== null) {\n          Object.assign(shellProps, window.__INITIAL_DATA__.shellData);\n        } else if (Shell.getInitialProps) {\n          Object.assign(shellProps, await Shell.getInitialProps());\n        }\n        render(createElement(Shell, shellProps, createElement(Entry)), document.getElementById(\"root\"), { driver: DriverUniversal, hydrate: true });\n      ";
    } else {
      // common web app
      appRenderMethod = 'render(createElement(Entry), document.getElementById("root"), { driver: DriverUniversal, hydrate: withSSR });';
    }

    appRender += "\n      const renderApp = async function() {\n        // process App.getInitialProps\n        if (withSSR && window.__INITIAL_DATA__.appData !== null) {\n          Object.assign(appProps, window.__INITIAL_DATA__.appData);\n        } else if (definedApp.getInitialProps) {\n          Object.assign(appProps, await definedApp.getInitialProps());\n        }\n        " + appRenderMethod + "\n      }\n      if (withSSR) {\n        getCurrentComponent(appProps.routerConfig.routes, true)().then(function(InitialComponent) {\n          if (InitialComponent !== null) {\n            appProps.routerConfig.InitialComponent = InitialComponent;\n          }\n          renderApp();\n        });\n      } else {\n        renderApp();\n      }\n    ";
  }
  /**
   * Example format of routes:
   * [
   *  {
   *    "path": "/page1",
   *    "component": "pages/page1"
   *  }
   * ]
   */


  var assembleRoutes = routes.map(function (route, index) {
    // First level function to support hooks will autorun function type state,
    // Second level function to support rax-use-router rule autorun function type component.
    var dynamicImportComponent = "() =>\n      import(/* webpackChunkName: \"" + route.component.replace(/\//g, '_') + "\" */ '" + getDepPath(route.component, _this.rootContext) + "')\n      .then((mod) => () => interopRequire(mod))\n    ";
    var importComponent = "() => () => interopRequire(require('" + getDepPath(route.component, _this.rootContext) + "'))";
    return "routes.push({\n      index: " + index + ",\n      regexp: " + pathToRegexp(route.path).toString() + ",\n      path: '" + route.path + "',\n      component: " + (options.type === 'web' ? dynamicImportComponent : importComponent) + "\n    });";
  }).join('\n');
  var source = "\n    import definedApp from '" + this.resourcePath + "';\n    import { render, createElement } from '" + renderMoudle + "';\n    import { " + historyMemory[historyType] + " as createHistory } from 'history';\n    import { _invokeAppCycle } from 'universal-app-runtime';\n    import DriverUniversal from 'driver-universal';\n    " + importMods + "\n\n    const interopRequire = (mod) => mod && mod.__esModule ? mod.default : mod;\n    const withSSR = !!window.__INITIAL_DATA__;\n\n    const getRouterConfig = () => {\n      const routes = [];\n      " + assembleRoutes + "\n      return {\n        history: createHistory(),\n        routes,\n      };\n    };\n\n    " + "\n    const appProps = {\n      routerConfig: getRouterConfig(),\n    };\n\n    let appLaunched = false;\n\n    function Entry() {\n      const app = definedApp(appProps);\n      const startOptions = {};\n\n      if (!appLaunched) {\n        appLaunched = true;\n        _invokeAppCycle('launch', startOptions);\n      }\n\n      return app;\n    }\n\n    " + appRender + "\n  ";

  var _babel$transformSync = babel.transformSync(source, babelConfig),
      code = _babel$transformSync.code;

  return code;
};
/**
 * Get app.json content at picth loader.
 * @param remainingRequest
 * @param precedingRequest
 * @param data
 */


module.exports.pitch = function (remainingRequest, precedingRequest, data) {
  data.appConfig = null; // Provide default value.

  try {
    var configPath = this.resourcePath.replace(/\.js$/, '.json');
    var rawContent = this.fs.readFileSync(configPath).toString();
    data.appConfig = JSON.parse(rawContent);
    this.addDependency(configPath);
  } catch (err) {
    throw new Error('Can not get app.json, please check.');
  }
};
/**
 * ./pages/foo -> based on src, return original
 * /pages/foo -> based on rootContext
 * pages/foo -> based on src, add prefix: './'
 */


function getDepPath(path, rootContext) {
  if (rootContext === void 0) {
    rootContext = '';
  }

  if (path[0] === '.') {
    return path;
  } else if (path[0] === '/') {
    return join(rootContext, path);
  } else {
    return './' + path;
  }
}

==> universal-app-shell-loader-0.2.3.tgz: package/lib/index.js <==
"use strict";

var _require = require('path'),
    join = _require.join;

var _require2 = require('loader-utils'),
    getOptions = _require2.getOptions;

var _require3 = require('fs'),
    existsSync = _require3.existsSync;

var pathToRegexp = require('path-to-regexp');

var getDepPath = require('./getDepPath');

var getSourceCode = require('./getSourceCode');

var babel = require('@babel/core');

var _require4 = require('rax-compile-config'),
    getBabelConfig = _require4.getBabelConfig;

var babelConfig = getBabelConfig();
var historyMemory = {
  hash: 'createHashHistory',
  memory: 'createMemoryHistory',
  browser: 'createBrowserHistory'
};
/**
 * Universal App Shell Loader for Rax.
 */

module.exports = function (content) {
  var _this = this;

  var options = getOptions(this) || {};
  var renderModule = options.renderModule || 'rax';

  if (!this.data.appConfig) {
    return content;
  }

  var _this$data$appConfig = this.data.appConfig,
      routes = _this$data$appConfig.routes,
      _this$data$appConfig$ = _this$data$appConfig.historyType,
      historyType = _this$data$appConfig$ === void 0 ? 'hash' : _this$data$appConfig$;

  if (!Array.isArray(routes)) {
    this.emitError(new Error('Unsupported field in app.json: routes.'));
    routes = [];
  }

  var appRender = '';
  var importMods = '';
  /**
   * Weex only support memory history.
   */

  if (options.type === 'weex') {
    historyType = 'memory';
    appRender = 'render(createElement(Entry), null, { driver: DriverUniversal });';
  }
  /**
   * Web only compatible with 750rpx.
   */


  if (options.type === 'web') {
    var appRenderMethod = '';
    importMods += 'import { getCurrentComponent } from "rax-pwa";';

    if (existsSync(join(this.rootContext, 'src/shell/index.jsx'))) {
      // app shell
      appRender += "import Shell from \"" + getDepPath('shell/index', this.rootContext) + "\";";
      appRenderMethod = "\n        // process Shell.getInitialProps\n        // use global props appProps as shell default props\n        const shellProps = {...appProps};\n        if (withSSR && window.__INITIAL_DATA__.shellData !== null) {\n          Object.assign(shellProps, window.__INITIAL_DATA__.shellData);\n        } else if (Shell.getInitialProps) {\n          Object.assign(shellProps, await Shell.getInitialProps());\n        }\n        render(createElement(Shell, shellProps, createElement(Entry)), document.getElementById(\"root\"), { driver: DriverUniversal, hydrate: true });\n      ";
    } else {
      // common web app
      appRenderMethod = 'render(createElement(Entry), document.getElementById("root"), { driver: DriverUniversal, hydrate: withSSR });';
    }

    appRender += "\n      const renderApp = async function() {\n        // process App.getInitialProps\n        if (withSSR && window.__INITIAL_DATA__.appData !== null) {\n          Object.assign(appProps, window.__INITIAL_DATA__.appData);\n        } else if (definedApp.getInitialProps) {\n          Object.assign(appProps, await definedApp.getInitialProps());\n        }\n        " + appRenderMethod + "\n      }\n      if (withSSR) {\n        getCurrentComponent(appProps.routerConfig.routes, true)().then(function(InitialComponent) {\n          if (InitialComponent !== null) {\n            appProps.routerConfig.InitialComponent = InitialComponent;\n          }\n          renderApp();\n        });\n      } else {\n        renderApp();\n      }\n    ";
  }
  /**
   * Example format of routes:
   * [
   *  {
   *    "path": "/page1",
   *    "component": "pages/page1"
   *  }
   * ]
   */


  var assembleRoutes = routes.map(function (route, index) {
    // First level function to support hooks will autorun function type state,
    // Second level function to support rax-use-router rule autorun function type component.
    var dynamicImportComponent = "() =>\n      import(/* webpackChunkName: \"" + route.component.replace(/\//g, '_') + "\" */ '" + getDepPath(route.component, _this.rootContext) + "')\n      .then((mod) => () => interopRequire(mod))\n    ";
    var importComponent = "() => () => interopRequire(require('" + getDepPath(route.component, _this.rootContext) + "'))";
    return "routes.push({\n      index: " + index + ",\n      regexp: " + pathToRegexp(route.path).toString() + ",\n      path: '" + route.path + "',\n      component: " + (options.type === 'web' ? dynamicImportComponent : importComponent) + "\n    });";
  }).join('\n');
  var source = getSourceCode({
    appRender: appRender,
    assembleRoutes: assembleRoutes,
    importMods: importMods,
    routes: routes,
    renderModule: renderModule,
    definedAppPath: this.resourcePath,
    historyMemory: historyMemory[historyType],
    isMultiPageWebApp: options.isMultiPageWebApp,
    routeIndex: options.routeIndex
  });

  var _babel$transformSync = babel.transformSync(source, babelConfig),
      code = _babel$transformSync.code;

  return code;
};
/**
 * Get app.json content at picth loader.
 * @param remainingRequest
 * @param precedingRequest
 * @param data
 */


module.exports.pitch = function (remainingRequest, precedingRequest, data) {
  data.appConfig = null; // Provide default value.

  try {
    var configPath = this.resourcePath.replace(/\.js$/, '.json');
    var rawContent = this.fs.readFileSync(configPath).toString();
    data.appConfig = JSON.parse(rawContent);
    this.addDependency(configPath);
  } catch (err) {
    throw new Error('Can not get app.json, please check.');
  }
};
